<?php
/**
 * @package    JMyLife
 * @subpackage Components
 * @version    1.0.16
 * @copyright  2009-2010 Jeff Channell
 * administrator/components/com_jmylife/helpers/html.php
 * @license

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 * @since     1.0.13
 */
// no direct access
defined('_JEXEC') or die('Restricted access');
jimport('joomla.filesystem.file');
if (!class_exists('JmylifeConfiguration')) {
	$configfile = JPATH_ROOT.DS.'components'.DS.'com_jmylife'.DS.'libraries'.DS.'configuration.php';
	if( JFile::exists( $configfile ) ) require_once( $configfile );
}

class JmylifeHtmlHelper
{
	private static $_instance;
	private $cfg;
	private $purifier;

	function __construct() {
		$this->cfg = JmylifeConfiguration::getInstance();
	}

	function getInstance() {
		if (!self::$_instance) {
			self::$_instance = new JmylifeHtmlHelper();
		}
		return self::$_instance;
	}

	/**
	 * alert
	 * @param  string   string to alert
	 * @return string   javascript alert
	 */
	function alert($string) {
		return '<script type="text/javascript">alert("'.htmlspecialchars($string).'");</script>';
	}

	/**
	 * boolRadio
	 * @param  string   name of radio element
	 * @param  string   label of radio element
	 * @param  bool     value
	 * @return string   html radio yes/no element
	 */
	function boolRadio($name, $label, $value) {
		$label = $this->tag('label', JText::_($label), array('for' => $name));
		$elem = JHTML::_('select.booleanlist', $name, '', $value, 'COM_JMYLIFE_CORE_BOOL_YES', 'COM_JMYLIFE_CORE_BOOL_NO');
		return $label.$elem;
	}

	/**
	 * link
	 * @param  string   link url
	 * @param  string   link text
	 * @param  array    link attributes
	 * @return string   html for link
	 */
	function link($href, $contents, $attributes=null) {
		if (!is_array($attributes)) {
			$attributes = array();
		}
		$attributes['href'] = $href;
		return $this->tag('a', $contents, $attributes);
	}

	/**
	 * image
	 * @param  string
	 * @param  array or null
	 * @return string
	 */
	function image($src, $attributes=null) {
		if (!is_array($attributes)) {
			$attributes = array();
		}
		$attributes['src'] = $src;
		return $this->tag('img', null, $attributes);
	}

	/**
	 * tag
	 * @param  string
	 * @param  string or null
	 * @param  array or null
	 * @return string
	 */
	function tag($tag, $contents=null, $attributes=null) {
		$attr = array();
		$attrString = '';
		if (is_array($attributes) && count($attributes)) {
			foreach ($attributes as $key => $val) {
				$key = htmlspecialchars($key);
				$val = htmlspecialchars($val);
				$attr[] = "{$key}=\"{$val}\"";
			}
			$attrString = ' '.implode(' ', $attr).' ';
		}
		if ($contents) {
			return "<{$tag}{$attrString}>{$contents}</{$tag}>";
		}
		return "<{$tag}{$attrString}/>";
	}

	/**
	 * clean
	 * @param  string
	 * @return string
	 */
	function clean($str='', $quotes=ENT_QUOTES, $charset='UTF-8') {
		return htmlentities($str, $quotes, $charset);
	}

	/**
	 * unclean
	 * @param  string
	 * @return string
	 */
	function unclean($str='', $quotes=ENT_QUOTES, $charset='UTF-8') {
		return html_entity_decode(str_replace('&#8203;', '', $str), $quotes, $charset);
	}

	/**
	 * strip
	 * @param  string
	 * @param  bool
	 * @return string
	 */
	function strip($string, $br2nl=false) {
		if ($br2nl) {
			$string = preg_replace('`<br\S*?>`Di', "\n", $string);
		}
		$string = strip_tags($string);
		return $string;
	}

	/**
	 * purify
	 * @param  string
	 * @return string
	 */
	function purify($string) {
		$purifier = $this->_getPurifier();
		return $purifier->purify($string);
	}

	/**
	 * fromBB
	 * @param  string
	 * @param  bool
	 * @return string
	 */
	function fromBB($str, $strip=false) {
		// additional cleanup
		$str = $this->purify($str);
		return $str;
	}

	function roundies() {
		if ($this->cfg->getInt('site_roundies', 1)) {
			$radius = $this->cfg->getInt('roundies_radius', 4);
			if (0 < $radius) {
				$doc = JFactory::getDocument();
				$doc->addStyleDeclaration(".jmylifeRound{-webkit-border-radius:{$radius}px;-moz-border-radius:{$radius}px;-khtml-border-radius:{$radius}px;border-radius:{$radius}px;}");
				if (isset($_SERVER['HTTP_USER_AGENT']) && false !== strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') && $this->cfg->getInt('ie_roundies')) {
					$doc->addScript(JURI::base().'components/com_jmylife/assets/js/DD_roundies_0.0.2a-min.js');
					$doc->addScriptDeclaration("DD_roundies.addRule('.jmylifeRound', '{$radius}px');");
				}
			}
		}
	}

	function _getPurifier() {
		if (empty($this->purifier)) {
			JLoader::import('components.com_jmylife.libraries.htmlpurifier.loader', JPATH_ROOT, '');
			$this->purifier = new HTMLPurifier();
		}
		return $this->purifier;
	}

}